@@ -52,7 +52,7 @@ def valid_apply_ref(ref):
         parts = ref.split("/")
         return (
             len(parts) == 3
-            and parts[0] == "tf"
+            and parts[0] == "prov"
             and parts[1] == "apply"
             and valid_id(parts[2])
         )
