@@ -53,22 +53,23 @@ class ChangeRef:
 
 
 class PlanRef:
-    def __init__(self, sid: str, uid: str, chid: str):
+    def __init__(self, sid: str, change_ref: ChangeRef):
         self.sid = sid
-        self.uid = uid
-        self.chid = chid
-        self.name = "tf/plan/{}/{}/{}".format(self.sid, self.uid, self.chid)
+        self.change_ref = change_ref
+        self.name = "prov/plan/{}/{}".format(self.sid, self.change_ref.name)
 
     @staticmethod
     def parse(branch: str):
         parts = branch.split("/")
-        return PlanRef(*parts[2:])
+        sid = parts[2]
+        change_ref = ChangeRef(*parts[4:])
+        return PlanRef(sid, change_ref)
 
 
 class ApplyRef:
     def __init__(self, sid: str):
         self.sid = sid
-        self.name = "tf/apply/{}".format(self.sid)
+        self.name = "prov/apply/{}".format(self.sid)
 
     @staticmethod
     def parse(branch: str):
@@ -86,8 +87,8 @@ class Repo:
 def parse_branch(branch: str):
     if branch.startswith("change"):
         return ChangeRef.parse(branch)
-    if branch.startswith("tf/apply"):
+    if branch.startswith("prov/apply"):
         return ApplyRef.parse(branch)
-    if branch.startswith("tf/plan"):
+    if branch.startswith("prov/plan"):
         return PlanRef.parse(branch)
     return None
